@@ -313,10 +313,25 @@ enum InterfaceKeyType
 	INTERFACEKEY_A_SLEEP_WAIT,
 	INTERFACEKEY_A_SLEEP_DAWN,
 	INTERFACEKEY_A_WAIT,
+	INTERFACEKEY_A_SHORT_WAIT,
 	INTERFACEKEY_A_ATTACK,
 	INTERFACEKEY_A_ATTACK_CONFIRM,
+	INTERFACEKEY_QUICK_ATTACK,
+	INTERFACEKEY_HEAVY_ATTACK,
+	INTERFACEKEY_WILD_ATTACK,
+	INTERFACEKEY_PRECISE_ATTACK,
+	INTERFACEKEY_CHARGE_ATTACK,
+	INTERFACEKEY_MULTI_ATTACK,
 	INTERFACEKEY_A_LOOK,
 	INTERFACEKEY_A_SEARCH,
+	INTERFACEKEY_A_ODOR,
+	INTERFACEKEY_A_DISPLAY_ODOR,
+	INTERFACEKEY_A_YIELD,
+	INTERFACEKEY_A_DISPLAY_TRACKS,
+	INTERFACEKEY_A_FRESHEST_TRACK,
+	INTERFACEKEY_A_INV_DRAW_WEAPON,
+	INTERFACEKEY_A_JUMP,
+	INTERFACEKEY_A_HOLD,
 	INTERFACEKEY_A_TALK,
 	INTERFACEKEY_A_INTERACT,
 	INTERFACEKEY_A_ACTION,
@@ -338,6 +353,7 @@ enum InterfaceKeyType
 	INTERFACEKEY_A_MOVEMENT,
 	INTERFACEKEY_A_MOVEMENT_SWIM,
 	INTERFACEKEY_A_SNEAK,
+	INTERFACEKEY_A_SPEED_SNEAK,
 	INTERFACEKEY_A_CENTER,
 	INTERFACEKEY_A_COMPANIONS,
 	INTERFACEKEY_A_BUILDING,
@@ -362,6 +378,11 @@ enum InterfaceKeyType
 	INTERFACEKEY_A_LOG_SITES,
 	INTERFACEKEY_A_LOG_SUBREGIONS,
 	INTERFACEKEY_A_LOG_FEATURE_LAYERS,
+	INTERFACEKEY_A_LOG_PEOPLE,
+	INTERFACEKEY_A_LOG_AGREEMENTS,
+	INTERFACEKEY_A_LOG_EVENTS,
+	INTERFACEKEY_A_LOG_BESTIARY,
+	INTERFACEKEY_A_LOG_FILTER,
 	INTERFACEKEY_A_LOG_ZOOM_CURRENT_LOCATION,
 	INTERFACEKEY_A_LOG_ZOOM_SELECTED,
 	INTERFACEKEY_A_LOG_LINE,
@@ -554,6 +575,7 @@ enum InterfaceKeyType
 	INTERFACEKEY_HOTKEY_BUILDING_MACHINE_GEAR_ASSEMBLY,
 	INTERFACEKEY_HOTKEY_BUILDING_MACHINE_AXLE_VERTICAL,
 	INTERFACEKEY_HOTKEY_BUILDING_MACHINE_AXLE_HORIZONTAL,
+	INTERFACEKEY_HOTKEY_BUILDING_MACHINE_ROLLERS,
 	INTERFACEKEY_HOTKEY_BUILDING_SIEGEENGINE_BALLISTA,
 	INTERFACEKEY_HOTKEY_BUILDING_SIEGEENGINE_CATAPULT,
 	INTERFACEKEY_HOTKEY_BUILDING_TRAP_STONE,
@@ -570,6 +592,8 @@ enum InterfaceKeyType
 	INTERFACEKEY_HOTKEY_BUILDING_CONSTRUCTION_STAIR_DOWN,
 	INTERFACEKEY_HOTKEY_BUILDING_CONSTRUCTION_STAIR_UPDOWN,
 	INTERFACEKEY_HOTKEY_BUILDING_CONSTRUCTION_FORTIFICATION,
+	INTERFACEKEY_HOTKEY_BUILDING_CONSTRUCTION_TRACK,
+	INTERFACEKEY_HOTKEY_BUILDING_CONSTRUCTION_TRACK_STOP,
 	INTERFACEKEY_HOTKEY_BUILDING_WORKSHOP_LEATHER,
 	INTERFACEKEY_HOTKEY_BUILDING_WORKSHOP_QUERN,
 	INTERFACEKEY_HOTKEY_BUILDING_WORKSHOP_MILLSTONE,
@@ -623,6 +647,11 @@ enum InterfaceKeyType
 	INTERFACEKEY_BUILDING_TRIGGER_MIN_MAGMA_DOWN,
 	INTERFACEKEY_BUILDING_TRIGGER_MAX_MAGMA_UP,
 	INTERFACEKEY_BUILDING_TRIGGER_MAX_MAGMA_DOWN,
+	INTERFACEKEY_BUILDING_TRIGGER_ENABLE_TRACK_CART,
+	INTERFACEKEY_BUILDING_TRIGGER_MIN_TRACK_CART_DOWN,
+	INTERFACEKEY_BUILDING_TRIGGER_MIN_TRACK_CART_UP,
+	INTERFACEKEY_BUILDING_TRIGGER_MAX_TRACK_CART_DOWN,
+	INTERFACEKEY_BUILDING_TRIGGER_MAX_TRACK_CART_UP,
 	INTERFACEKEY_BUILDING_TRIGGER_ENABLE_CREATURE,
 	INTERFACEKEY_BUILDING_TRIGGER_ENABLE_LOCALS,
 	INTERFACEKEY_BUILDING_TRIGGER_RESETS,
@@ -630,10 +659,20 @@ enum InterfaceKeyType
 	INTERFACEKEY_BUILDING_TRIGGER_MIN_SIZE_DOWN,
 	INTERFACEKEY_BUILDING_TRIGGER_MAX_SIZE_UP,
 	INTERFACEKEY_BUILDING_TRIGGER_MAX_SIZE_DOWN,
+	INTERFACEKEY_BUILDING_TRIGGER_MIN_SIZE_UP_PLUS,
+	INTERFACEKEY_BUILDING_TRIGGER_MIN_SIZE_DOWN_PLUS,
+	INTERFACEKEY_BUILDING_TRIGGER_MAX_SIZE_UP_PLUS,
+	INTERFACEKEY_BUILDING_TRIGGER_MAX_SIZE_DOWN_PLUS,
+	INTERFACEKEY_BUILDING_ROLLERS_SPEED_UP,
+	INTERFACEKEY_BUILDING_ROLLERS_SPEED_DOWN,
+	INTERFACEKEY_BUILDING_TRACK_STOP_FRICTION_UP,
+	INTERFACEKEY_BUILDING_TRACK_STOP_FRICTION_DOWN,
+	INTERFACEKEY_BUILDING_TRACK_STOP_DUMP,
 	INTERFACEKEY_DESTROYBUILDING,
 	INTERFACEKEY_SUSPENDBUILDING,
 	INTERFACEKEY_BUILDINGLIST_ZOOM_T,
 	INTERFACEKEY_BUILDINGLIST_ZOOM_Q,
+	INTERFACEKEY_RECENTER_ON_LEVER,
 
 	WORKSHOPKEY_START,
 	INTERFACEKEY_HOTKEY_MAKE_ASH=WORKSHOPKEY_START,
@@ -755,11 +794,8 @@ enum InterfaceKeyType
 	INTERFACEKEY_HOTKEY_FARMER_SHEAR_CREATURE,
 	INTERFACEKEY_HOTKEY_FARMER_SPIN_THREAD,
 	INTERFACEKEY_HOTKEY_MILL_MILL,
-	INTERFACEKEY_HOTKEY_KENNEL_TRAIN_HUNT,
 	INTERFACEKEY_HOTKEY_KENNEL_CATCH_VERMIN,
 	INTERFACEKEY_HOTKEY_KENNEL_TAME_VERMIN,
-	INTERFACEKEY_HOTKEY_KENNEL_TAME_UNIT,
-	INTERFACEKEY_HOTKEY_KENNEL_TRAIN_WAR,
 	INTERFACEKEY_HOTKEY_FISHERY_PROCESS,
 	INTERFACEKEY_HOTKEY_FISHERY_EXTRACT,
 	INTERFACEKEY_HOTKEY_FISHERY_CATCH,
@@ -805,10 +841,13 @@ enum InterfaceKeyType
 	INTERFACEKEY_HOTKEY_TRAP_CHAIN,
 	INTERFACEKEY_HOTKEY_TRAP_CAGE,
 	INTERFACEKEY_HOTKEY_TRAP_GEAR_ASSEMBLY,
+	INTERFACEKEY_HOTKEY_TRAP_TRACK_STOP,
 	INTERFACEKEY_HOTKEY_TRAP_PULL_LEVER,
 
 	PILEZONEKEY_START,
 	INTERFACEKEY_BUILDJOB_STOCKPILE_MASTER=PILEZONEKEY_START,
+	INTERFACEKEY_BUILDJOB_STOCKPILE_LINK_ANYWHERE,
+	INTERFACEKEY_BUILDJOB_STOCKPILE_GIVE_TO,
 	INTERFACEKEY_BUILDJOB_STOCKPILE_DELETE_CHILD,
 	INTERFACEKEY_BUILDJOB_STOCKPILE_SETTINGS,
 	INTERFACEKEY_BUILDJOB_STOCKPILE_BARREL_UP,
@@ -819,6 +858,7 @@ enum InterfaceKeyType
 	INTERFACEKEY_BUILDJOB_STOCKPILE_BIN_DOWN,
 	INTERFACEKEY_BUILDJOB_STOCKPILE_BIN_ZERO,
 	INTERFACEKEY_BUILDJOB_STOCKPILE_BIN_MAX,
+	INTERFACEKEY_BUILDJOB_STOCKPILE_WHEELBARROW,
 	INTERFACEKEY_STOCKPILE_ANIMAL,
 	INTERFACEKEY_STOCKPILE_FOOD,
 	INTERFACEKEY_STOCKPILE_WEAPON,
@@ -852,6 +892,7 @@ enum InterfaceKeyType
 	INTERFACEKEY_CIVZONE_NEXT,
 	INTERFACEKEY_CIVZONE_WATER_SOURCE,
 	INTERFACEKEY_CIVZONE_FISH,
+	INTERFACEKEY_CIVZONE_GATHER,
 	INTERFACEKEY_CIVZONE_DUMP,
 	INTERFACEKEY_CIVZONE_POND,
 	INTERFACEKEY_CIVZONE_HOSPITAL,
@@ -859,11 +900,16 @@ enum InterfaceKeyType
 	INTERFACEKEY_CIVZONE_CLAY_COLLECT,
 	INTERFACEKEY_CIVZONE_ACTIVE,
 	INTERFACEKEY_CIVZONE_MEETING,
+	INTERFACEKEY_CIVZONE_ANIMAL_TRAINING,
 	INTERFACEKEY_CIVZONE_PEN,
 	INTERFACEKEY_CIVZONE_PEN_OPTIONS,
 	INTERFACEKEY_CIVZONE_POND_OPTIONS,
 	INTERFACEKEY_CIVZONE_POND_WATER,
 	INTERFACEKEY_CIVZONE_HOSPITAL_OPTIONS,
+	INTERFACEKEY_CIVZONE_GATHER_OPTIONS,
+	INTERFACEKEY_CIVZONE_GATHER_OPTIONS_PICK_TREES,
+	INTERFACEKEY_CIVZONE_GATHER_OPTIONS_PICK_SHRUBS,
+	INTERFACEKEY_CIVZONE_GATHER_OPTIONS_GATHER_FALLEN,
 
 	STOCKORDERKEY_START,
 	INTERFACEKEY_STORES_VIEW=STOCKORDERKEY_START,
@@ -873,6 +919,9 @@ enum InterfaceKeyType
 	INTERFACEKEY_STORES_DUMP,
 	INTERFACEKEY_STORES_HIDE,
 	INTERFACEKEY_PET_BUTCHER,
+	INTERFACEKEY_ANIMAL_SELECT_TRAINER,
+	INTERFACEKEY_ANIMAL_WAR_TRAINING,
+	INTERFACEKEY_ANIMAL_HUNTING_TRAINING,
 	INTERFACEKEY_KITCHEN_COOK,
 	INTERFACEKEY_KITCHEN_BREW,
 	INTERFACEKEY_ORDERS_AUTOFORBID,
@@ -958,11 +1007,34 @@ enum InterfaceKeyType
 	INTERFACEKEY_D_JOBLIST,
 	INTERFACEKEY_D_UNITLIST,
 	INTERFACEKEY_D_LOOK,
+	INTERFACEKEY_D_HAULING,
+	INTERFACEKEY_D_HAULING_NEW_ROUTE,
+	INTERFACEKEY_D_HAULING_NEW_STOP,
+	INTERFACEKEY_D_HAULING_REMOVE,
+	INTERFACEKEY_D_HAULING_PROMOTE,
+	INTERFACEKEY_D_HAULING_VEHICLE,
+	INTERFACEKEY_D_HAULING_NICKNAME,
+	INTERFACEKEY_D_HAULING_STOP_NEW_DEPART,
+	INTERFACEKEY_D_HAULING_STOP_NEW_LINK,
+	INTERFACEKEY_D_HAULING_STOP_REMOVE,
+	INTERFACEKEY_D_HAULING_STOP_SL_SELECT_PILE,
+	INTERFACEKEY_D_HAULING_STOP_SL_TAKE_GIVE,
+	INTERFACEKEY_D_HAULING_STOP_LC_DIR,
+	INTERFACEKEY_D_HAULING_STOP_LC_MODE,
+	INTERFACEKEY_D_HAULING_STOP_LC_TIMER_UP,
+	INTERFACEKEY_D_HAULING_STOP_LC_TIMER_DOWN,
+	INTERFACEKEY_D_HAULING_STOP_LC_FULLNESS_UP,
+	INTERFACEKEY_D_HAULING_STOP_LC_FULLNESS_DOWN,
+	INTERFACEKEY_D_HAULING_STOP_LC_MORE_LESS,
+	INTERFACEKEY_D_HAULING_STOP_LC_DESIRED_TOTAL,
+	INTERFACEKEY_D_HAULING_STOP_LC_CHANGE,
+	INTERFACEKEY_D_HAULING_STOP_LC_ADVANCED,
 	INTERFACEKEY_D_BURROWS,
 	INTERFACEKEY_D_BURROWS_ADD,
 	INTERFACEKEY_D_BURROWS_DELETE,
 	INTERFACEKEY_D_BURROWS_DEFINE,
 	INTERFACEKEY_D_BURROWS_ADD_UNIT,
+	INTERFACEKEY_D_BURROWS_WORKSHOP_LIMIT,
 	INTERFACEKEY_D_BURROWS_CENTER,
 	INTERFACEKEY_D_BURROWS_NAME,
 	INTERFACEKEY_D_BURROWS_CHANGE_SELECTION,
@@ -994,6 +1066,7 @@ enum InterfaceKeyType
 	INTERFACEKEY_D_LOOK_DUMP,
 	INTERFACEKEY_D_LOOK_MELT,
 	INTERFACEKEY_D_LOOK_HIDE,
+	INTERFACEKEY_D_LOOK_FOLLOW,
 	INTERFACEKEY_D_LOOK_ARENA_CREATURE,
 	INTERFACEKEY_D_LOOK_ARENA_ADV_MODE,
 	INTERFACEKEY_D_LOOK_ARENA_WATER,
@@ -1004,6 +1077,18 @@ enum InterfaceKeyType
 	INTERFACEKEY_ARENA_CREATURE_BLANK_LIST,
 	INTERFACEKEY_ARENA_CREATURE_REMOVE_ITEM,
 	INTERFACEKEY_ARENA_CREATURE_UNDEAD,
+	INTERFACEKEY_ARENA_CREATURE_STRING,
+	INTERFACEKEY_ARENA_CONFLICT_STATE_1,
+	INTERFACEKEY_ARENA_CONFLICT_STATE_2,
+	INTERFACEKEY_ARENA_MORALE,
+	INTERFACEKEY_ARENA_WEATHER,
+	INTERFACEKEY_ARENA_WEATHER_SNOW,
+	INTERFACEKEY_ARENA_WEATHER_MUD,
+	INTERFACEKEY_ARENA_WEATHER_CLEAR_SPATTER,
+	INTERFACEKEY_D_LOOK_ARENA_TREE,
+	INTERFACEKEY_ARENA_TREE_FILTER,
+	INTERFACEKEY_ARENA_TREE_AGE,
+	INTERFACEKEY_D_LOOK_ARENA_MOUNT,
 	INTERFACEKEY_ASSIGNTRADE_VIEW,
 	INTERFACEKEY_ASSIGNTRADE_STRING,
 	INTERFACEKEY_ASSIGNTRADE_EXCLUDE_PROHIBITED,
@@ -1062,6 +1147,7 @@ enum InterfaceKeyType
 	INTERFACEKEY_DESIGNATE_SMOOTH,
 	INTERFACEKEY_DESIGNATE_ENGRAVE,
 	INTERFACEKEY_DESIGNATE_FORTIFY,
+	INTERFACEKEY_DESIGNATE_TRACK,
 	INTERFACEKEY_DESIGNATE_TOGGLE_ENGRAVING,
 	INTERFACEKEY_DESIGNATE_UNDO,
 	INTERFACEKEY_DESIGNATE_REMOVE_CONSTRUCTION,
@@ -1080,6 +1166,7 @@ enum InterfaceKeyType
 	INTERFACEKEY_UNITVIEW_INV,
 	INTERFACEKEY_UNITVIEW_PRF,
 	INTERFACEKEY_UNITVIEW_WND,
+	INTERFACEKEY_UNITVIEW_FOLLOW,
 	INTERFACEKEY_UNITVIEW_NEXT,
 	INTERFACEKEY_UNITVIEW_SLAUGHTER,
 	INTERFACEKEY_UNITVIEW_GEN_COMBAT,
@@ -1087,9 +1174,11 @@ enum InterfaceKeyType
 	INTERFACEKEY_UNITVIEW_GEN_MISC,
 	INTERFACEKEY_UNITVIEW_PRF_PROF,
 	INTERFACEKEY_UNITVIEW_PRF_PET,
-	INTERFACEKEY_UNITVIEW_PRF_PET_HUNT,
-	INTERFACEKEY_UNITVIEW_PRF_PET_WAR,
 	INTERFACEKEY_UNITVIEW_PRF_VIEW,
+	INTERFACEKEY_UNITVIEW_PRF_NEW_SQUAD,
+	INTERFACEKEY_UNITVIEW_PRF_REMOVE_FROM_SQUAD,
+	INTERFACEKEY_UNITVIEW_PRF_NAME_CURRENT_SQUAD,
+	INTERFACEKEY_UNITVIEW_PRF_NAME_SELECTED_SQUAD,
 	INTERFACEKEY_CUSTOMIZE_UNIT_NICKNAME,
 	INTERFACEKEY_CUSTOMIZE_UNIT_PROFNAME,
 
@@ -1130,6 +1219,7 @@ enum InterfaceKeyType
 	INTERFACEKEY_D_MILITARY_ADD_UNIFORM,
 	INTERFACEKEY_D_MILITARY_DELETE_UNIFORM,
 	INTERFACEKEY_D_MILITARY_NAME_UNIFORM,
+	INTERFACEKEY_D_MILITARY_NAME_SQUAD,
 	INTERFACEKEY_D_MILITARY_ADD_ARMOR,
 	INTERFACEKEY_D_MILITARY_ADD_PANTS,
 	INTERFACEKEY_D_MILITARY_ADD_HELM,
@@ -1287,7 +1377,6 @@ enum InterfaceKeyType
 	INTERFACEKEY_STRING_A124,
 	INTERFACEKEY_STRING_A125,
 	INTERFACEKEY_STRING_A126,
-	INTERFACEKEY_STRING_A127,
 	INTERFACEKEY_STRING_A128,
 	INTERFACEKEY_STRING_A129,
 	INTERFACEKEY_STRING_A130,
